@@ -44,7 +44,7 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 5485 2008-05-21 19:37:48Z lowell $"
+__version__ = "$Id: cloghandler.py 5490 2008-05-22 19:03:46Z lowell $"
 __author__ = "Lowell Alleman"
 
 
@@ -177,6 +177,15 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
                 # release thread lock
                 Handler.release(self)
     
+    def close(self):
+        """
+        Closes the stream.
+        """
+        if not self.stream.closed:
+            self.stream.flush()
+            self.stream.close()
+        Handler.close(self)
+    
     def flush(self):
         """ flush():  Do nothing.
 
